@@ -1,4 +1,4 @@
-# $Header: /raid/cvsroot/DBIx/DBIx-SearchBuilder/SearchBuilder/Handle/Oracle.pm,v 1.9 2001/03/07 15:17:01 jesse Exp $
+# $Header: /raid/cvsroot/DBIx/DBIx-SearchBuilder/SearchBuilder/Handle/Oracle.pm,v 1.10 2001/03/14 07:09:06 jesse Exp $
 
 package DBIx::SearchBuilder::Handle::Oracle;
 use DBIx::SearchBuilder::Handle;
@@ -39,14 +39,13 @@ sub Connect  {
   
   my $dsn = "dbi:$args{'Driver'}:$args{'Database'}";   
 
-  my $handle = DBI->connect_cached($dsn, $args{'User'}, $args{'Password'}) || die "Connect Failed $DBI::errstr\n" ;
+  my $DBIHandle = DBI->connect_cached($dsn, $args{'User'}, $args{'Password'}) || die "Connect Failed $DBI::errstr\n" ;
 
   #Set the handle 
-  $self->dbh($handle);
+  $self->dbh($DBIHandle);
 
 
     
-    $self->SUPER::Connect(@_);
     
     $self->dbh->{LongTruncOk}=1;
     $self->dbh->{LongReadLen}=8000;
